@@ -9,12 +9,12 @@
 #include "dist/mongoose/mongoose.h"
 #include "dist/sds/sds.h"
 
-#include "src/lib/cacertstore.h"
-#include "src/lib/cert.h"
-#include "src/lib/config.h"
-#include "src/lib/config_def.h"
+#include "src/lib/config/cacertstore.h"
+#include "src/lib/config/cert.h"
+#include "src/lib/config/config.h"
+#include "src/lib/config/config_def.h"
+#include "src/lib/config/handle_options.h"
 #include "src/lib/filehandler.h"
-#include "src/lib/handle_options.h"
 #include "src/lib/log.h"
 #include "src/lib/mem.h"
 #include "src/lib/mpdclient.h"
