@@ -11,7 +11,7 @@
 #ifndef MYMPD_API_FILESYSTEM_H
 #define MYMPD_API_FILESYSTEM_H
 
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 sds mympd_api_browse_filesystem(struct t_mympd_state *mympd_state, struct t_partition_state *partition_state,
         sds buffer, unsigned request_id, sds path, unsigned offset, unsigned limit, sds searchstr, const struct t_fields *tagcols);
