@@ -11,7 +11,7 @@
 #ifndef MYMPD_API_SEARCH_H
 #define MYMPD_API_SEARCH_H
 
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 sds mympd_api_search_songs(struct t_partition_state *partition_state, struct t_stickerdb_state *stickerdb, 
         sds buffer, unsigned request_id, const char *expression, const char *sort, bool sortdesc,
