@@ -11,7 +11,7 @@
 #ifndef MYMPD_API_STATS_H
 #define MYMPD_API_STATS_H
 
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 sds mympd_api_stats_get(struct t_partition_state *partition_state, sds buffer, unsigned request_id);
 #endif
