@@ -11,11 +11,11 @@
 #include "compile_time.h"
 #include "src/mympd_api/status.h"
 
+#include "src/lib/config/mympd_state.h"
 #include "src/lib/datetime.h"
 #include "src/lib/json/json_print.h"
 #include "src/lib/json/json_rpc.h"
 #include "src/lib/log.h"
-#include "src/lib/mympd_state.h"
 #include "src/lib/sds_extras.h"
 #include "src/lib/timer.h"
 #include "src/lib/utility.h"
