@@ -13,7 +13,7 @@
 
 #include "dist/sds/sds.h"
 #include "src/lib/api.h"
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 void mympd_set_mpd_failure(struct t_partition_state *partition_state, const char *errormessage);
 bool mympd_check_error_and_recover(struct t_partition_state *partition_state, sds *error, const char *command);
