@@ -12,7 +12,7 @@
 #define MYMPD_MPD_CLIENT_IDLE_H
 
 #include "src/lib/api.h"
-#include "src/lib/mympd_state.h"
+#include "src/lib/config/mympd_state.h"
 
 void mympd_client_idle(struct t_mympd_state *mympd_state, struct t_work_request *request);
 void mympd_client_scrobble(struct t_mympd_state *mympd_state, struct t_partition_state *partition_state);
