@@ -37,24 +37,6 @@ static sds get_tag_values(const struct mpd_song *song, enum mpd_tag_type tag,
  * Public functions
  */
 
-/**
- * Returns the mpd database last modification time
- * @param partition_state pointer to partition specific states
- * @return last modification time
- */
-time_t mympd_client_get_db_mtime(struct t_partition_state *partition_state) {
-    time_t mtime = 0;
-    struct mpd_stats *stats = mpd_run_stats(partition_state->conn);
-    if (stats != NULL) {
-        mtime = (time_t)mpd_stats_get_db_update_time(stats);
-        mpd_stats_free(stats);
-    }
-    if (mympd_check_error_and_recover(partition_state, NULL, "mpd_run_stats") == false) {
-        mtime = 0;
-    }
-    return mtime;
-}
-
 /**
  * Checks if tag is a multivalue tag
  * @param tag mpd tag type
@@ -152,7 +134,7 @@ sds get_sort_key(sds key, enum sort_by_type sort_by, enum mpd_tag_type sort_tag,
         }
     }
     key = sdscatfmt(key, "::%s", mpd_song_get_uri(song));
-    sds_utf8_tolower(key);
+    key = sds_utf8_normalize(key);
     return key;
 }
 
