@@ -20,6 +20,7 @@
 #include "src/lib/msg_queue.h"
 #include "src/lib/sds_extras.h"
 #include "src/lib/utility.h"
+#include "src/mympd_client/database.h"
 #include "src/mympd_client/errorhandler.h"
 #include "src/mympd_client/search.h"
 #include "src/mympd_client/tags.h"
@@ -162,7 +163,7 @@ static bool album_cache_create(struct t_mympd_worker_state *mympd_worker_state,
     do {
         if (mpd_search_db_songs(mympd_worker_state->partition_state->conn, false) == false ||
             mpd_search_add_expression(mympd_worker_state->partition_state->conn, search_expression) == false ||
-            mpd_search_add_window(mympd_worker_state->partition_state->conn, start, end) == false)
+            mympd_client_add_search_window(mympd_worker_state->partition_state->conn, start, end) == false)
         {
             MYMPD_LOG_ERROR("default", "Cache update failed");
             mpd_search_cancel(mympd_worker_state->partition_state->conn);
