@@ -16,6 +16,6 @@
 
 #include <stdbool.h>
 
-bool request_handler_playlistart(struct mg_connection *nc, struct mg_http_message *hm, struct t_mg_user_data *mg_user_data);
+bool request_handler_playlistart(struct mg_connection *nc, struct mg_http_message *hm);
 
 #endif
